/*
 *  Top-level include file to be used for all (internal) source files.
 *
 *  Source files should not include individual header files, as they
 *  have not been designed to be individually included.
 */

#if !defined(DUK_INTERNAL_H_INCLUDED)
#define DUK_INTERNAL_H_INCLUDED

/*
 *  The 'duktape.h' header provides the public API, but also handles all
 *  compiler and platform specific feature detection, Duktape feature
 *  resolution, inclusion of system headers, etc.  These have been merged
 *  because the public API is also dependent on e.g. detecting appropriate
 *  C types which is quite platform/compiler specific especially for a non-C99
 *  build.  The public API is also dependent on the resolved feature set.
 *
 *  Some actions taken by the merged header (such as including system headers)
 *  are not appropriate for building a user application.  The define
 *  DUK_COMPILING_DUKTAPE allows the merged header to skip/include some
 *  sections depending on what is being built.
 */

#define DUK_COMPILING_DUKTAPE
#include "third_party/duktape/duktape.h"

/*
 *  Duktape includes (other than duk_features.h)
 *
 *  The header files expect to be included in an order which satisfies header
 *  dependencies correctly (the headers themselves don't include any other
 *  includes).  Forward declarations are used to break circular struct/typedef
 *  dependencies.
 */

#include "third_party/duktape/duk_dblunion.h"
#include "third_party/duktape/duk_fltunion.h"
#include "third_party/duktape/duk_replacements.h"
#include "third_party/duktape/duk_jmpbuf.h"
#include "third_party/duktape/duk_exception.h"
#include "third_party/duktape/duk_forwdecl.h"
#include "third_party/duktape/duk_tval.h"      /* builtins need e.g. duk_tval tag definitions */
#include "third_party/duktape/duk_builtins.h"  /* autogenerated: strings and built-in object init data */

#include "third_party/duktape/duk_util.h"
#include "third_party/duktape/duk_strings.h"
#include "third_party/duktape/duk_js_bytecode.h"
#include "third_party/duktape/duk_lexer.h"
#include "third_party/duktape/duk_js_compiler.h"
#include "third_party/duktape/duk_regexp.h"
#include "third_party/duktape/duk_heaphdr.h"
#include "third_party/duktape/duk_refcount.h"
#include "third_party/duktape/duk_api_internal.h"
#include "third_party/duktape/duk_hstring.h"
#include "third_party/duktape/duk_hobject.h"
#include "third_party/duktape/duk_hcompfunc.h"
#include "third_party/duktape/duk_hnatfunc.h"
#include "third_party/duktape/duk_hboundfunc.h"
#include "third_party/duktape/duk_hbufobj.h"
#include "third_party/duktape/duk_hthread.h"
#include "third_party/duktape/duk_harray.h"
#include "third_party/duktape/duk_henv.h"
#include "third_party/duktape/duk_hbuffer.h"
#include "third_party/duktape/duk_hproxy.h"
#include "third_party/duktape/duk_heap.h"
#include "third_party/duktape/duk_debugger.h"
#include "third_party/duktape/duk_debug.h"
#include "third_party/duktape/duk_error.h"
#include "third_party/duktape/duk_unicode.h"
#include "third_party/duktape/duk_json.h"
#include "third_party/duktape/duk_js.h"
#include "third_party/duktape/duk_numconv.h"
#include "third_party/duktape/duk_bi_protos.h"
#include "third_party/duktape/duk_selftest.h"

#endif  /* DUK_INTERNAL_H_INCLUDED */
